@@ -1,24 +1,3 @@
-# linearly transforms a vector of numbers to a new range
-
-rescale<-function(x,newrange) {
- if(missing(x) | missing(newrange)) {
-  usage.string<-paste("Usage: rescale(x,newrange)\n",
-   "\twhere x is a numeric object and newrange is the new min and max\n",
-   sep="",collapse="")
-  stop(usage.string)
- }
- if(is.numeric(x) && is.numeric(newrange)) {
-  xrange<-range(x)
-  if(xrange[1] == xrange[2]) stop("rescale: can't rescale a constant vector!")
-  mfac<-(newrange[2]-newrange[1])/(xrange[2]-xrange[1])
-  return(newrange[1]+(x-xrange[1])*mfac)
- }
- else {
-  warning("Only numeric objects can be rescaled")
-  return(x)
- }
-}
-
 # plots data as radial lines or a polygon on a 24 hour "clockface" going 
 # clockwise. clock.pos should be in decimal hours between 0 and 24.
 # Remember to convert hour/minute values to hour/decimal values.
